Class: SmartyStreets::USStreet::Lookup

Inherits:
JSONAble
  • Object
show all
Defined in:
lib/smartystreets_ruby_sdk/us_street/lookup.rb

Overview

In addition to holding all of the input data for this lookup, this class also will contain the result of the lookup after it comes back from the API.

See "https://smartystreets.com/docs/cloud/us-street-api#input-fields"

@match

Must be set to 'strict', 'enhanced', or 'invalid'. Constants for these are in match_type.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from JSONAble

#from_json!, #to_json

Constructor Details

#initialize(street = nil, street2 = nil, secondary = nil, city = nil, state = nil, zipcode = nil, lastline = nil, addressee = nil, urbanization = nil, match = nil, candidates = 0, input_id = nil, county_source = nil, format = nil) ⇒ Lookup

Returns a new instance of Lookup.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 14

def initialize(street=nil, street2=nil, secondary=nil, city=nil, state=nil, zipcode=nil, lastline=nil,
               addressee=nil, urbanization=nil, match=nil, candidates=0, input_id=nil, county_source=nil, format=nil)
  @input_id = input_id
  @street = street
  @street2 = street2
  @secondary = secondary
  @city = city
  @state = state
  @zipcode = zipcode
  @lastline = lastline
  @addressee = addressee
  @urbanization = urbanization
  @match = match
  @candidates = candidates
  @format = format
  @county_source = county_source
  @custom_param_hash = {}
  @result = []
end

Instance Attribute Details

#addressee ⇒ Object

Returns the value of attribute addressee.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def addressee
  @addressee
end

#candidates ⇒ Object

Returns the value of attribute candidates.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def candidates
  @candidates
end

#city ⇒ Object

Returns the value of attribute city.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def city
  @city
end

#county_source ⇒ Object

Returns the value of attribute county_source.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def county_source
  @county_source
end

#custom_param_hash ⇒ Object

Returns the value of attribute custom_param_hash.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def custom_param_hash
  @custom_param_hash
end

#format ⇒ Object

Returns the value of attribute format.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def format
  @format
end

#input_id ⇒ Object

Returns the value of attribute input_id.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def input_id
  @input_id
end

#lastline ⇒ Object

Returns the value of attribute lastline.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def lastline
  @lastline
end

#match ⇒ Object

Returns the value of attribute match.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def match
  @match
end

#result ⇒ Object

Returns the value of attribute result.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def result
  @result
end

#secondary ⇒ Object

Returns the value of attribute secondary.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def secondary
  @secondary
end

#state ⇒ Object

Returns the value of attribute state.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def state
  @state
end

#street ⇒ Object

Returns the value of attribute street.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def street
  @street
end

#street2 ⇒ Object

Returns the value of attribute street2.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def street2
  @street2
end

#urbanization ⇒ Object

Returns the value of attribute urbanization.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def urbanization
  @urbanization
end

#zipcode ⇒ Object

Returns the value of attribute zipcode.



11
12
13
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 11

def zipcode
  @zipcode
end

Instance Method Details

#add_custom_parameter(parameter, value) ⇒ Object



34
35
36
# File 'lib/smartystreets_ruby_sdk/us_street/lookup.rb', line 34

def add_custom_parameter(parameter, value)
  @custom_param_hash[parameter] = value
end